"""
Generated by Sideko (sideko.dev)
"""

import typing
import httpx


def remove_none_from_dict(
    original: typing.Dict[str, typing.Optional[typing.Any]],
) -> typing.Dict[str, typing.Any]:
    new: typing.Dict[str, typing.Any] = {}
    for key, value in original.items():
        if value is not None:
            new[key] = value
    return new


def is_binary_content_type(content_type: str) -> bool:
    """Check if the content type indicates binary data."""
    binary_types = [
        "application/octet-stream",
        "application/pdf",
        "application/zip",
        "image/",
        "audio/",
        "video/",
        "application/msword",
        "application/vnd.openxmlformats-officedocument",
        "application/x-binary",
        "application/vnd.ms-excel",
        "application/vnd.ms-powerpoint",
    ]
    return any(binary_type in content_type for binary_type in binary_types)


def get_content_type(headers: httpx.Headers) -> str:
    """Get content type in a case-insensitive manner."""
    for key, value in headers.items():
        if key.lower() == "content-type":
            return value.lower()
    return ""



"""
Generated by Sideko (sideko.dev)
"""

import typing_extensions
import pydantic


class PostV1AiImageUpscalerBodyAssets(typing_extensions.TypedDict):
    """
    Provide the assets for upscaling
    """

    image_file_path: typing_extensions.Required[str]
    """
    The image to upscale. This is the `file_path` field from the response of the [upload urls API](/docs/api/tag/files/post/v1/files/upload-urls)
    """


class _SerializerPostV1AiImageUpscalerBodyAssets(pydantic.BaseModel):
    """
    Serializer for PostV1AiImageUpscalerBodyAssets handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    image_file_path: str = pydantic.Field(alias="image_file_path")



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic

from .get_v1_video_projects_id_response_download import (
    GetV1VideoProjectsIdResponseDownload,
)
from .get_v1_video_projects_id_response_error import GetV1VideoProjectsIdResponseError


class GetV1VideoProjectsIdResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    created_at: str = pydantic.Field(alias="created_at")

    download: typing.Optional[GetV1VideoProjectsIdResponseDownload] = pydantic.Field(
        alias="download", default=None
    )
    """
    The download url and expiration date of the video project
    """

    enabled: bool = pydantic.Field(alias="enabled")
    """
    Indicates whether the resource is deleted
    """

    end_seconds: float = pydantic.Field(alias="end_seconds")
    """
    The end time of the input video in seconds
    """

    error: typing.Optional[GetV1VideoProjectsIdResponseError] = pydantic.Field(
        alias="error", default=None
    )
    """
    In the case of an error, this object will contain the error encountered during video render
    """

    fps: float = pydantic.Field(alias="fps")
    """
    Frame rate of the video. If the status is not 'complete', the frame rate is an estimate and will be adjusted when the video completes.
    """

    height: float = pydantic.Field(alias="height")
    """
    The height of the final output video. The maximum height depends on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
    """

    id: str = pydantic.Field(alias="id")
    """
    Unique ID of the video. This value can be used in the [get video project API](/api/tag/video-projects/get/v1/video-projects/{id}) to fetch additional details such as status
    """

    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    """
    The name of the video.
    """

    start_seconds: float = pydantic.Field(alias="start_seconds")
    """
    The start time of the input video in seconds
    """

    status: typing_extensions.Literal[
        "canceled", "complete", "draft", "error", "queued", "rendering"
    ] = pydantic.Field(alias="status")
    """
    The status of the video.
    """

    total_frame_cost: float = pydantic.Field(alias="total_frame_cost")
    """
    The amount of frames used to generate the video. If the status is not 'complete', the cost is an estimate and will be adjusted when the video completes.
    """

    type_field: typing_extensions.Literal[
        "ANIMATION",
        "FACE_SWAP",
        "IMAGE_TO_VIDEO",
        "LIP_SYNC",
        "TEXT_TO_VIDEO",
        "VIDEO_TO_VIDEO",
    ] = pydantic.Field(alias="type")

    width: float = pydantic.Field(alias="width")
    """
    The width of the final output video. The maximum width depends on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
    """



"""
Generated by Sideko (sideko.dev)
"""

import abc
import typing

from pydantic import BaseModel

from .request import RequestConfig


class AuthProvider(abc.ABC):
    @abc.abstractmethod
    def add_to_request(self, cfg: RequestConfig) -> RequestConfig:
        """Adds relevant auth to request kwargs"""


class AuthBasic(BaseModel, AuthProvider):
    username: typing.Optional[str]
    password: typing.Optional[str]

    def add_to_request(self, cfg: RequestConfig) -> RequestConfig:
        if self.username is not None and self.password is not None:
            cfg["auth"] = (self.username, self.password)

        return cfg


class AuthBearer(BaseModel, AuthProvider):
    val: typing.Optional[str]

    def add_to_request(self, cfg: RequestConfig) -> RequestConfig:
        if self.val is not None:
            # Add bearer header auth val
            headers = cfg.get("headers", dict())
            headers["Authorization"] = f"Bearer {self.val}"
            cfg["headers"] = headers

        return cfg


class AuthKeyQuery(BaseModel, AuthProvider):
    query_name: str
    val: typing.Optional[str]

    def add_to_request(self, cfg: RequestConfig) -> RequestConfig:
        if self.val is not None:
            # Add query auth value
            params = cfg.get("params", dict())
            params[self.query_name] = self.val
            cfg["params"] = params

        return cfg


class AuthKeyHeader(BaseModel, AuthProvider):
    header_name: str
    val: typing.Optional[str]

    def add_to_request(self, cfg: RequestConfig) -> RequestConfig:
        if self.val is not None:
            # Add header auth val
            headers = cfg.get("headers", {})
            headers[self.header_name] = self.val
            cfg["headers"] = headers

        return cfg


class AuthKeyCookie(BaseModel, AuthProvider):
    cookie_name: str
    val: typing.Optional[str]

    def add_to_request(self, cfg: RequestConfig) -> RequestConfig:
        if self.val is not None:
            # Add cookie auth val
            cookies = cfg.get("cookies", dict())
            cookies[self.cookie_name] = self.val
            cfg["cookies"] = cookies

        return cfg



"""
Generated by Sideko (sideko.dev)
"""

import typing
import pydantic

from .post_v1_files_upload_urls_response_items_item import (
    PostV1FilesUploadUrlsResponseItemsItem,
)


class PostV1FilesUploadUrlsResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    items: typing.List[PostV1FilesUploadUrlsResponseItemsItem] = pydantic.Field(
        alias="items"
    )



"""
Generated by Sideko (sideko.dev)
"""

from typing import Any, Dict, Type, Union, Sequence
from urllib.parse import quote_plus


import httpx
from typing_extensions import TypedDict, Required, NotRequired
from pydantic import TypeAdapter, BaseModel

QueryParams = Dict[
    str, Union[httpx._types.PrimitiveData, Sequence[httpx._types.PrimitiveData]]
]


class RequestConfig(TypedDict):
    method: Required[str]
    url: Required[httpx._types.URLTypes]
    content: NotRequired[httpx._types.RequestContent]
    data: NotRequired[httpx._types.RequestData]
    files: NotRequired[httpx._types.RequestFiles]
    json: NotRequired[Any]
    params: NotRequired[QueryParams]
    headers: NotRequired[Dict[str, str]]
    cookies: NotRequired[Dict[str, str]]
    auth: NotRequired[httpx._types.AuthTypes]
    follow_redirects: NotRequired[bool]
    timeout: NotRequired[httpx._types.TimeoutTypes]
    extensions: NotRequired[httpx._types.RequestExtensions]


class RequestOptions(TypedDict):
    """
    Attributes:
        - timeout: int. The number of seconds to await an API call before timing out.

        - additional_headers: typing.Dict[str, typing.Any]. A dictionary containing additional parameters to spread into the request's header dict

        - additional_params: typing.Dict[str, typing.Any]. A dictionary containing additional parameters to spread into the request's query parameters dict

    """

    timeout: NotRequired[int]
    additional_headers: NotRequired[Dict[str, str]]
    additional_params: NotRequired[QueryParams]


def default_request_options() -> RequestOptions:
    """Returns default request options"""
    return {}


def model_dump(item: Any) -> Any:
    if isinstance(item, list):
        return [model_dump(i) for i in item]

    if isinstance(item, BaseModel):
        return item.model_dump(exclude_unset=True, by_alias=True)
    else:
        return item


def to_encodable(*, item: Any, dump_with: Type) -> Any:
    adapter = TypeAdapter(dump_with)
    validated_item = adapter.validate_python(item)
    return model_dump(validated_item)


def encode_param(
    value: Any, explode: bool
) -> Union[httpx._types.PrimitiveData, Sequence[httpx._types.PrimitiveData]]:
    if isinstance(value, (list, dict)) and not explode:
        return quote_plus(",".join(map(str, value)))
    else:
        return value



"""
Generated by Sideko (sideko.dev)
"""

import pydantic


class PostV1AiImageGeneratorResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    frame_cost: float = pydantic.Field(alias="frame_cost")

    id: str = pydantic.Field(alias="id")
    """
    Unique ID of the image. This value can be used in the [get image project API](/api/tag/image-projects/get/v1/image-projects/{id}) to fetch additional details such as status
    """



"""
Generated by Sideko (sideko.dev)
"""

import pydantic


class PostV1VideoToVideoResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    estimated_frame_cost: float = pydantic.Field(alias="estimated_frame_cost")
    """
    Estimated cost of the video in terms of number of frames needed to render the video. Frames will be adjusted when the video completes
    """

    id: str = pydantic.Field(alias="id")
    """
    Unique ID of the video. This value can be used in the [get video project API](/api/tag/video-projects/get/v1/video-projects/{id}) to fetch additional details such as status
    """



"""
Generated by Sideko (sideko.dev)
"""

import pydantic


class PostV1FilesUploadUrlsResponseItemsItem(pydantic.BaseModel):
    """
    PostV1FilesUploadUrlsResponseItemsItem
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    expires_at: str = pydantic.Field(alias="expires_at")
    """
    when the upload url expires, and will need to request a new one.
    """

    file_path: str = pydantic.Field(alias="file_path")
    """
    this value is used in APIs that needs assets, such as image_file_path, video_file_path, and audio_file_path
    """

    upload_url: str = pydantic.Field(alias="upload_url")
    """
    Used to upload the file to storage, send a PUT request with the file as data to upload.
    """



"""
Generated by Sideko (sideko.dev)
"""

from .get_v1_image_projects_id_response_downloads_item import (
    GetV1ImageProjectsIdResponseDownloadsItem,
)
from .get_v1_image_projects_id_response_error import GetV1ImageProjectsIdResponseError
from .get_v1_video_projects_id_response_download import (
    GetV1VideoProjectsIdResponseDownload,
)
from .get_v1_video_projects_id_response_error import GetV1VideoProjectsIdResponseError
from .post_v1_ai_headshot_generator_response import PostV1AiHeadshotGeneratorResponse
from .post_v1_ai_image_generator_response import PostV1AiImageGeneratorResponse
from .post_v1_ai_image_upscaler_response import PostV1AiImageUpscalerResponse
from .post_v1_ai_photo_editor_response import PostV1AiPhotoEditorResponse
from .post_v1_ai_qr_code_generator_response import PostV1AiQrCodeGeneratorResponse
from .post_v1_animation_response import PostV1AnimationResponse
from .post_v1_face_swap_response import PostV1FaceSwapResponse
from .post_v1_face_swap_photo_response import PostV1FaceSwapPhotoResponse
from .post_v1_files_upload_urls_response_items_item import (
    PostV1FilesUploadUrlsResponseItemsItem,
)
from .post_v1_image_to_video_response import PostV1ImageToVideoResponse
from .post_v1_lip_sync_response import PostV1LipSyncResponse
from .post_v1_text_to_video_response import PostV1TextToVideoResponse
from .post_v1_video_to_video_response import PostV1VideoToVideoResponse
from .get_v1_image_projects_id_response import GetV1ImageProjectsIdResponse
from .get_v1_video_projects_id_response import GetV1VideoProjectsIdResponse
from .post_v1_files_upload_urls_response import PostV1FilesUploadUrlsResponse


__all__ = [
    "GetV1ImageProjectsIdResponse",
    "GetV1ImageProjectsIdResponseDownloadsItem",
    "GetV1ImageProjectsIdResponseError",
    "GetV1VideoProjectsIdResponse",
    "GetV1VideoProjectsIdResponseDownload",
    "GetV1VideoProjectsIdResponseError",
    "PostV1AiHeadshotGeneratorResponse",
    "PostV1AiImageGeneratorResponse",
    "PostV1AiImageUpscalerResponse",
    "PostV1AiPhotoEditorResponse",
    "PostV1AiQrCodeGeneratorResponse",
    "PostV1AnimationResponse",
    "PostV1FaceSwapPhotoResponse",
    "PostV1FaceSwapResponse",
    "PostV1FilesUploadUrlsResponse",
    "PostV1FilesUploadUrlsResponseItemsItem",
    "PostV1ImageToVideoResponse",
    "PostV1LipSyncResponse",
    "PostV1TextToVideoResponse",
    "PostV1VideoToVideoResponse",
]



"""
Generated by Sideko (sideko.dev)
"""

from .api_error import ApiError
from .auth import (
    AuthKeyQuery,
    AuthBasic,
    AuthBearer,
    AuthProvider,
    AuthKeyCookie,
    AuthKeyHeader,
)
from .base_client import AsyncBaseClient, BaseClient, SyncBaseClient
from .binary_response import BinaryResponse
from .request import (
    encode_param,
    to_encodable,
    RequestOptions,
    default_request_options,
    QueryParams,
)
from .response import from_encodable

__all__ = [
    "ApiError",
    "AsyncBaseClient",
    "BaseClient",
    "BinaryResponse",
    "RequestOptions",
    "default_request_options",
    "SyncBaseClient",
    "AuthKeyQuery",
    "AuthBasic",
    "AuthBearer",
    "AuthProvider",
    "AuthKeyCookie",
    "AuthKeyHeader",
    "to_encodable",
    "encode_param",
    "from_encodable",
    "QueryParams",
]



"""
Generated by Sideko (sideko.dev)
"""

import typing_extensions
import pydantic


class PostV1AiQrCodeGeneratorBodyStyle(typing_extensions.TypedDict):
    """
    PostV1AiQrCodeGeneratorBodyStyle
    """

    art_style: typing_extensions.Required[str]
    """
    To use our templates, pass in one of Watercolor, Cyberpunk City, Ink Landscape, Interior Painting, Japanese Street, Mech, Minecraft, Picasso Painting, Game Map, Spaceship, Chinese Painting, Winter Village, or pass any custom art style.
    """


class _SerializerPostV1AiQrCodeGeneratorBodyStyle(pydantic.BaseModel):
    """
    Serializer for PostV1AiQrCodeGeneratorBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    art_style: str = pydantic.Field(alias="art_style")



"""
Generated by Sideko (sideko.dev)
"""

import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
)
from magic_hour.types import models, params


class AiImageUpscalerClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client
        # register sync resources

    # register sync api methods
    def create(
        self,
        *,
        data: typing.Optional[params.PostV1AiImageUpscalerBody] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.PostV1AiImageUpscalerResponse:
        """
        Upscale your image using AI. Each 2x upscale costs 50 frames, and 4x upscale costs 200 frames.

        POST /v1/ai-image-upscaler
        """

        # start -- build request data
        _json = to_encodable(
            item=data, dump_with=params._SerializerPostV1AiImageUpscalerBody
        )
        # end -- build request data

        # start -- send sync request
        return self._base_client.request(
            method="POST",
            path="/v1/ai-image-upscaler",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.PostV1AiImageUpscalerResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send sync request


class AsyncAiImageUpscalerClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client
        # register async resources

    # register async api methods
    async def create(
        self,
        *,
        data: typing.Optional[params.PostV1AiImageUpscalerBody] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.PostV1AiImageUpscalerResponse:
        """
        Upscale your image using AI. Each 2x upscale costs 50 frames, and 4x upscale costs 200 frames.

        POST /v1/ai-image-upscaler
        """

        # start -- build request data
        _json = to_encodable(
            item=data, dump_with=params._SerializerPostV1AiImageUpscalerBody
        )
        # end -- build request data

        # start -- send async request
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-image-upscaler",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.PostV1AiImageUpscalerResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send async request



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic


class PostV1AnimationBodyStyle(typing_extensions.TypedDict):
    """
    Defines the style of the output video
    """

    art_style: typing_extensions.Required[
        typing_extensions.Literal[
            "3D Render",
            "90s Streets",
            "Abstract Minimalist",
            "Arcane",
            "Art Deco",
            "Bold Colored Illustration",
            "Cinematic Landscape",
            "Cinematic Miyazaki",
            "Cosmic",
            "Cubist",
            "Custom",
            "Cyberpunk",
            "Dark Graphic Illustration",
            "Dark Watercolor",
            "Directed by AI",
            "Double Exposure",
            "Faded Illustration",
            "Fantasy",
            "Futuristic Anime",
            "Impressionism",
            "Ink and Watercolor Portrait",
            "Inkpunk",
            "Intricate Abstract Lines Portrait",
            "Jackson Pollock",
            "Landscape Painting",
            "Low Poly",
            "Miniatures",
            "Minimal Cold Futurism",
            "Oil Painting",
            "Old School Comic",
            "Overgrown",
            "Painted Cityscape",
            "Painterly Illustration",
            "Photograph",
            "Pixar",
            "Pixel Art",
            "Postapocalyptic",
            "Sin City",
            "Soft Delicate Matte Portrait",
            "Spooky",
            "Studio Ghibli Film Still",
            "Synthwave",
            "Traditional Watercolor",
            "Van Gogh",
            "Vibrant Matte Illustration",
            "Vintage Japanese Anime",
            "Woodcut",
        ]
    ]
    """
    The art style of the final output video
    """

    art_style_custom: typing_extensions.NotRequired[str]
    """
    Describe custom art style. This field is required if `art_style` is `Custom`
    """

    camera_effect: typing_extensions.Required[
        typing_extensions.Literal[
            "Accelerate",
            "Aggressive Zoom In - Audio Sync",
            "Aggressive Zoom Out - Audio Sync",
            "Boost Zoom In",
            "Boost Zoom Out",
            "Bounce In And Out",
            "Bounce Out",
            "Bounce Out - Audio Sync",
            "Bounce and Spin - Audio Sync",
            "Bounce in Place",
            "Cog in the Machine",
            "Devolve - Audio Sync",
            "Directed by AI",
            "Dramatic Zoom In",
            "Dramatic Zoom Out",
            "Drift Spin",
            "Earthquake Bounce",
            "Earthquake Bounce - Audio Sync",
            "Evolve - Audio Sync",
            "Heartbeat",
            "Hesitate In",
            "Jump",
            "Pan Left",
            "Pan Right",
            "Pulse - Audio Sync",
            "Pusher",
            "Pusher - Audio Sync",
            "Quadrant",
            "Rise and Climb",
            "Road Trip",
            "Rodeo",
            "Roll In",
            "Roll In - Audio Sync",
            "Rolling Bounces",
            "Rubber Band",
            "Simple Zoom In",
            "Simple Zoom Out",
            "Slice Bounce",
            "Slideshow",
            "Speed of Light",
            "Spin Bounce",
            "Sway Out",
            "Sway Out - Audio Sync",
            "Tilt Down",
            "Tilt Up",
            "Traverse",
            "Tron",
            "Vertigo",
            "Vertigo - Audio Sync",
            "Zoom In - Audio Sync",
            "Zoom In and Spin - Audio Sync",
            "Zoom Out - Audio Sync",
        ]
    ]

    prompt: typing.Optional[str]
    """
    The prompt used for the video. Prompt is required if `prompt_type` is `custom`. Otherwise this value is ignored
    """

    prompt_type: typing_extensions.Required[
        typing_extensions.Literal["ai_choose", "custom", "use_lyrics"]
    ]
    """
    
    * `custom` - use your own prompt for the video.
    * `use_lyrics` - Use the lyrics of the audio to create the prompt. If this option is selected, then `assets.audio_source` must be `file` or `youtube`.
    * `ai_choose` - Let AI write the prompt. If this option is selected, then `assets.audio_source` must be `file` or `youtube`.
    """

    transition_speed: typing_extensions.Required[int]
    """
    Change determines how quickly the video's content changes across frames. Higher = more rapid transitions. Lower = more stable visual experience.
    """


class _SerializerPostV1AnimationBodyStyle(pydantic.BaseModel):
    """
    Serializer for PostV1AnimationBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    art_style: typing_extensions.Literal[
        "3D Render",
        "90s Streets",
        "Abstract Minimalist",
        "Arcane",
        "Art Deco",
        "Bold Colored Illustration",
        "Cinematic Landscape",
        "Cinematic Miyazaki",
        "Cosmic",
        "Cubist",
        "Custom",
        "Cyberpunk",
        "Dark Graphic Illustration",
        "Dark Watercolor",
        "Directed by AI",
        "Double Exposure",
        "Faded Illustration",
        "Fantasy",
        "Futuristic Anime",
        "Impressionism",
        "Ink and Watercolor Portrait",
        "Inkpunk",
        "Intricate Abstract Lines Portrait",
        "Jackson Pollock",
        "Landscape Painting",
        "Low Poly",
        "Miniatures",
        "Minimal Cold Futurism",
        "Oil Painting",
        "Old School Comic",
        "Overgrown",
        "Painted Cityscape",
        "Painterly Illustration",
        "Photograph",
        "Pixar",
        "Pixel Art",
        "Postapocalyptic",
        "Sin City",
        "Soft Delicate Matte Portrait",
        "Spooky",
        "Studio Ghibli Film Still",
        "Synthwave",
        "Traditional Watercolor",
        "Van Gogh",
        "Vibrant Matte Illustration",
        "Vintage Japanese Anime",
        "Woodcut",
    ] = pydantic.Field(alias="art_style")
    art_style_custom: typing.Optional[str] = pydantic.Field(
        alias="art_style_custom", default=None
    )
    camera_effect: typing_extensions.Literal[
        "Accelerate",
        "Aggressive Zoom In - Audio Sync",
        "Aggressive Zoom Out - Audio Sync",
        "Boost Zoom In",
        "Boost Zoom Out",
        "Bounce In And Out",
        "Bounce Out",
        "Bounce Out - Audio Sync",
        "Bounce and Spin - Audio Sync",
        "Bounce in Place",
        "Cog in the Machine",
        "Devolve - Audio Sync",
        "Directed by AI",
        "Dramatic Zoom In",
        "Dramatic Zoom Out",
        "Drift Spin",
        "Earthquake Bounce",
        "Earthquake Bounce - Audio Sync",
        "Evolve - Audio Sync",
        "Heartbeat",
        "Hesitate In",
        "Jump",
        "Pan Left",
        "Pan Right",
        "Pulse - Audio Sync",
        "Pusher",
        "Pusher - Audio Sync",
        "Quadrant",
        "Rise and Climb",
        "Road Trip",
        "Rodeo",
        "Roll In",
        "Roll In - Audio Sync",
        "Rolling Bounces",
        "Rubber Band",
        "Simple Zoom In",
        "Simple Zoom Out",
        "Slice Bounce",
        "Slideshow",
        "Speed of Light",
        "Spin Bounce",
        "Sway Out",
        "Sway Out - Audio Sync",
        "Tilt Down",
        "Tilt Up",
        "Traverse",
        "Tron",
        "Vertigo",
        "Vertigo - Audio Sync",
        "Zoom In - Audio Sync",
        "Zoom In and Spin - Audio Sync",
        "Zoom Out - Audio Sync",
    ] = pydantic.Field(alias="camera_effect")
    prompt: typing.Optional[str] = pydantic.Field(alias="prompt")
    prompt_type: typing_extensions.Literal["ai_choose", "custom", "use_lyrics"] = (
        pydantic.Field(alias="prompt_type")
    )
    transition_speed: int = pydantic.Field(alias="transition_speed")



"""
Generated by Sideko (sideko.dev)
"""

import pydantic


class GetV1VideoProjectsIdResponseDownload(pydantic.BaseModel):
    """
    The download url and expiration date of the video project
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    expires_at: str = pydantic.Field(alias="expires_at")

    url: str = pydantic.Field(alias="url")



"""
Generated by Sideko (sideko.dev)
"""

import typing


class ApiError(Exception):
    status_code: typing.Optional[int]
    body: typing.Any

    def __init__(
        self, *, status_code: typing.Optional[int] = None, body: typing.Any = None
    ):
        self.status_code = status_code
        self.body = body

    def __str__(self) -> str:
        return f"status_code: {self.status_code}, body: {self.body}"



"""
Generated by Sideko (sideko.dev)
"""

import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
)
from magic_hour.types import models, params


class UploadUrlsClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client
        # register sync resources

    # register sync api methods
    def create(
        self,
        *,
        data: typing.Optional[params.PostV1FilesUploadUrlsBody] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.PostV1FilesUploadUrlsResponse:
        """
        Create a list of urls used to upload the assets needed to generate a video. Each video type has their own requirements on what assets are required. Please refer to the specific mode API for more details. The response array will be in the same order as the request body.
        
        Below is the list of valid extensions for each asset type:
        
        - video: mp4, mov, webm
        - audio: mp3, mpeg, wav, aac, aiff, flac
        - image: png, jpg, jpeg, webp, avif, jp2, tiff, bmp
        
        Note: `.gif` is supported for face swap API `video_file_path` field.
        
        After receiving the upload url, you can upload the file by sending a PUT request with the header `'Content-Type: application/octet-stream'`.
        
        For example using curl
        
        ```
        curl -X PUT -H 'Content-Type: application/octet-stream' \
          --data '@/path/to/file/video.mp4' \
          https://videos.magichour.ai/api-assets/id/video.mp4?auth-value=1234567890
        ```
        
        
        POST /v1/files/upload-urls
        """

        # start -- build request data
        _json = to_encodable(
            item=data, dump_with=params._SerializerPostV1FilesUploadUrlsBody
        )
        # end -- build request data

        # start -- send sync request
        return self._base_client.request(
            method="POST",
            path="/v1/files/upload-urls",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.PostV1FilesUploadUrlsResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send sync request


class AsyncUploadUrlsClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client
        # register async resources

    # register async api methods
    async def create(
        self,
        *,
        data: typing.Optional[params.PostV1FilesUploadUrlsBody] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.PostV1FilesUploadUrlsResponse:
        """
        Create a list of urls used to upload the assets needed to generate a video. Each video type has their own requirements on what assets are required. Please refer to the specific mode API for more details. The response array will be in the same order as the request body.
        
        Below is the list of valid extensions for each asset type:
        
        - video: mp4, mov, webm
        - audio: mp3, mpeg, wav, aac, aiff, flac
        - image: png, jpg, jpeg, webp, avif, jp2, tiff, bmp
        
        Note: `.gif` is supported for face swap API `video_file_path` field.
        
        After receiving the upload url, you can upload the file by sending a PUT request with the header `'Content-Type: application/octet-stream'`.
        
        For example using curl
        
        ```
        curl -X PUT -H 'Content-Type: application/octet-stream' \
          --data '@/path/to/file/video.mp4' \
          https://videos.magichour.ai/api-assets/id/video.mp4?auth-value=1234567890
        ```
        
        
        POST /v1/files/upload-urls
        """

        # start -- build request data
        _json = to_encodable(
            item=data, dump_with=params._SerializerPostV1FilesUploadUrlsBody
        )
        # end -- build request data

        # start -- send async request
        return await self._base_client.request(
            method="POST",
            path="/v1/files/upload-urls",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.PostV1FilesUploadUrlsResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send async request



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic

from .post_v1_text_to_video_body_style import (
    PostV1TextToVideoBodyStyle,
    _SerializerPostV1TextToVideoBodyStyle,
)


class PostV1TextToVideoBody(typing_extensions.TypedDict):
    """
    PostV1TextToVideoBody
    """

    end_seconds: typing_extensions.Required[float]
    """
    The total duration of the output video in seconds.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    orientation: typing_extensions.Required[
        typing_extensions.Literal["landscape", "portrait", "square"]
    ]
    """
    Determines the orientation of the output video
    """

    style: typing_extensions.Required[PostV1TextToVideoBodyStyle]


class _SerializerPostV1TextToVideoBody(pydantic.BaseModel):
    """
    Serializer for PostV1TextToVideoBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    end_seconds: float = pydantic.Field(alias="end_seconds")
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    orientation: typing_extensions.Literal["landscape", "portrait", "square"] = (
        pydantic.Field(alias="orientation")
    )
    style: _SerializerPostV1TextToVideoBodyStyle = pydantic.Field(alias="style")



"""
Generated by Sideko (sideko.dev)
"""

from magic_hour.core import AsyncBaseClient, SyncBaseClient
from magic_hour.resources.v1.image_projects import (
    AsyncImageProjectsClient,
    ImageProjectsClient,
)
from magic_hour.resources.v1.video_projects import (
    AsyncVideoProjectsClient,
    VideoProjectsClient,
)
from magic_hour.resources.v1.ai_headshot_generator import (
    AiHeadshotGeneratorClient,
    AsyncAiHeadshotGeneratorClient,
)
from magic_hour.resources.v1.ai_image_generator import (
    AiImageGeneratorClient,
    AsyncAiImageGeneratorClient,
)
from magic_hour.resources.v1.ai_image_upscaler import (
    AiImageUpscalerClient,
    AsyncAiImageUpscalerClient,
)
from magic_hour.resources.v1.ai_photo_editor import (
    AiPhotoEditorClient,
    AsyncAiPhotoEditorClient,
)
from magic_hour.resources.v1.ai_qr_code_generator import (
    AiQrCodeGeneratorClient,
    AsyncAiQrCodeGeneratorClient,
)
from magic_hour.resources.v1.animation import AnimationClient, AsyncAnimationClient
from magic_hour.resources.v1.face_swap import AsyncFaceSwapClient, FaceSwapClient
from magic_hour.resources.v1.face_swap_photo import (
    AsyncFaceSwapPhotoClient,
    FaceSwapPhotoClient,
)
from magic_hour.resources.v1.files import AsyncFilesClient, FilesClient
from magic_hour.resources.v1.image_to_video import (
    AsyncImageToVideoClient,
    ImageToVideoClient,
)
from magic_hour.resources.v1.lip_sync import AsyncLipSyncClient, LipSyncClient
from magic_hour.resources.v1.text_to_video import (
    AsyncTextToVideoClient,
    TextToVideoClient,
)
from magic_hour.resources.v1.video_to_video import (
    AsyncVideoToVideoClient,
    VideoToVideoClient,
)


class V1Client:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client
        # register sync resources
        self.image_projects = ImageProjectsClient(base_client=self._base_client)
        self.video_projects = VideoProjectsClient(base_client=self._base_client)
        self.ai_headshot_generator = AiHeadshotGeneratorClient(
            base_client=self._base_client
        )
        self.ai_image_generator = AiImageGeneratorClient(base_client=self._base_client)
        self.ai_image_upscaler = AiImageUpscalerClient(base_client=self._base_client)
        self.ai_photo_editor = AiPhotoEditorClient(base_client=self._base_client)
        self.ai_qr_code_generator = AiQrCodeGeneratorClient(
            base_client=self._base_client
        )
        self.animation = AnimationClient(base_client=self._base_client)
        self.face_swap = FaceSwapClient(base_client=self._base_client)
        self.face_swap_photo = FaceSwapPhotoClient(base_client=self._base_client)
        self.files = FilesClient(base_client=self._base_client)
        self.image_to_video = ImageToVideoClient(base_client=self._base_client)
        self.lip_sync = LipSyncClient(base_client=self._base_client)
        self.text_to_video = TextToVideoClient(base_client=self._base_client)
        self.video_to_video = VideoToVideoClient(base_client=self._base_client)

    # register sync api methods


class AsyncV1Client:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client
        # register async resources
        self.image_projects = AsyncImageProjectsClient(base_client=self._base_client)
        self.video_projects = AsyncVideoProjectsClient(base_client=self._base_client)
        self.ai_headshot_generator = AsyncAiHeadshotGeneratorClient(
            base_client=self._base_client
        )
        self.ai_image_generator = AsyncAiImageGeneratorClient(
            base_client=self._base_client
        )
        self.ai_image_upscaler = AsyncAiImageUpscalerClient(
            base_client=self._base_client
        )
        self.ai_photo_editor = AsyncAiPhotoEditorClient(base_client=self._base_client)
        self.ai_qr_code_generator = AsyncAiQrCodeGeneratorClient(
            base_client=self._base_client
        )
        self.animation = AsyncAnimationClient(base_client=self._base_client)
        self.face_swap = AsyncFaceSwapClient(base_client=self._base_client)
        self.face_swap_photo = AsyncFaceSwapPhotoClient(base_client=self._base_client)
        self.files = AsyncFilesClient(base_client=self._base_client)
        self.image_to_video = AsyncImageToVideoClient(base_client=self._base_client)
        self.lip_sync = AsyncLipSyncClient(base_client=self._base_client)
        self.text_to_video = AsyncTextToVideoClient(base_client=self._base_client)
        self.video_to_video = AsyncVideoToVideoClient(base_client=self._base_client)

    # register async api methods



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic

from .post_v1_ai_image_upscaler_body_assets import (
    PostV1AiImageUpscalerBodyAssets,
    _SerializerPostV1AiImageUpscalerBodyAssets,
)
from .post_v1_ai_image_upscaler_body_style import (
    PostV1AiImageUpscalerBodyStyle,
    _SerializerPostV1AiImageUpscalerBodyStyle,
)


class PostV1AiImageUpscalerBody(typing_extensions.TypedDict):
    """
    PostV1AiImageUpscalerBody
    """

    assets: typing_extensions.Required[PostV1AiImageUpscalerBodyAssets]
    """
    Provide the assets for upscaling
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    scale_factor: typing_extensions.Required[float]

    style: typing_extensions.Required[PostV1AiImageUpscalerBodyStyle]


class _SerializerPostV1AiImageUpscalerBody(pydantic.BaseModel):
    """
    Serializer for PostV1AiImageUpscalerBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerPostV1AiImageUpscalerBodyAssets = pydantic.Field(alias="assets")
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    scale_factor: float = pydantic.Field(alias="scale_factor")
    style: _SerializerPostV1AiImageUpscalerBodyStyle = pydantic.Field(alias="style")



"""
Generated by Sideko (sideko.dev)
"""

from json import JSONDecodeError
from typing import Any, List, TypeVar, Dict, Optional, Type, Union, cast

import httpx
from pydantic import BaseModel

from .api_error import ApiError
from .auth import AuthProvider
from .request import RequestConfig, RequestOptions, default_request_options, QueryParams
from .response import from_encodable
from .utils import is_binary_content_type, get_content_type
from .binary_response import BinaryResponse

NoneType = type(None)
T = TypeVar(
    "T",
    bound=Union[object, None, str, "BaseModel", List[Any], Dict[str, Any], Any],
)


class BaseClient:
    def __init__(
        self,
        *,
        base_url: str,
    ):
        self._base_url = base_url
        self._auths: Dict[str, AuthProvider] = {}

    def register_auth(self, auth_id: str, provider: AuthProvider):
        self._auths[auth_id] = provider

    def default_headers(self) -> Dict[str, str]:
        headers: Dict[str, str] = {
            "x-sideko-sdk-language": "Python",
        }
        return headers

    def get_base_url(self) -> str:
        return self._base_url

    def build_url(self, path: str) -> str:
        base = self._base_url
        if base.endswith("/"):
            base = base[:-1]
        if path.startswith("/"):
            path = path[1:]

        return f"{base}/{path}"

    def _apply_auth(
        self, *, cfg: RequestConfig, auth_names: List[str]
    ) -> RequestConfig:
        for auth_name in auth_names:
            auth_provider = self._auths.get(auth_name)
            if auth_provider is not None:
                cfg = auth_provider.add_to_request(cfg)

        return cfg

    def _apply_headers(
        self,
        *,
        cfg: RequestConfig,
        opts: RequestOptions,
        content_type: Optional[str] = None,
        explicit_headers: Optional[Dict[str, str]] = None,
    ) -> RequestConfig:
        headers = cfg.get("headers", {})
        headers.update(self.default_headers())

        if content_type is not None:
            headers["content-type"] = content_type

        if explicit_headers is not None:
            headers.update(explicit_headers)

        additional_headers = opts.get("additional_headers", None)
        if additional_headers is not None:
            headers.update(additional_headers)

        if len(headers) > 0:
            cfg["headers"] = headers

        return cfg

    def _apply_query_params(
        self,
        *,
        cfg: RequestConfig,
        opts: RequestOptions,
        query_params: Optional[QueryParams] = None,
    ) -> RequestConfig:
        params = cfg.get("params", {})

        if query_params is not None:
            params.update(query_params)

        additional_params = opts.get("additional_params", None)
        if additional_params is not None:
            params.update(additional_params)

        if len(params) > 0:
            cfg["params"] = params

        return cfg

    def _apply_timeout(
        self,
        *,
        cfg: RequestConfig,
        opts: RequestOptions,
    ) -> RequestConfig:
        timeout = opts.get("timeout", None)

        # TODO: timeout from base class
        if timeout is not None:
            cfg["timeout"] = timeout

        return cfg

    def _apply_body(
        self,
        *,
        cfg: RequestConfig,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        content: Optional[httpx._types.RequestContent] = None,
    ) -> RequestConfig:
        if data is not None:
            cfg["data"] = data

        if files is not None:
            cfg["files"] = files

        if json is not None:
            cfg["json"] = json

        if content is not None:
            cfg["content"] = content

        return cfg

    def build_request(
        self,
        *,
        method: str,
        path: str,
        auth_names: Optional[List[str]] = None,
        query_params: Optional[QueryParams] = None,
        headers: Optional[Dict[str, str]] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        content_type: Optional[str] = None,
        content: Optional[httpx._types.RequestContent] = None,
        request_options: Optional[RequestOptions] = None,
    ) -> RequestConfig:
        opts = request_options or default_request_options()
        req_cfg: RequestConfig = {"method": method, "url": self.build_url(path)}
        req_cfg = self._apply_auth(cfg=req_cfg, auth_names=auth_names or [])
        req_cfg = self._apply_headers(
            cfg=req_cfg, opts=opts, content_type=content_type, explicit_headers=headers
        )
        req_cfg = self._apply_query_params(
            cfg=req_cfg, opts=opts, query_params=query_params
        )
        req_cfg = self._apply_body(
            cfg=req_cfg, data=data, files=files, json=json, content=content
        )
        req_cfg = self._apply_timeout(cfg=req_cfg, opts=opts)

        return req_cfg

    def process_response(self, *, response=httpx.Response, cast_to: Type[T]) -> T:
        if 200 <= response.status_code < 300:
            content_type = get_content_type(response.headers)
            if response.status_code == 204 or cast_to == NoneType:
                return cast(T, None)
            elif cast_to == BinaryResponse:
                return cast(
                    T,
                    BinaryResponse(content=response.content, headers=response.headers),
                )
            else:
                if "json" in content_type or "form" in content_type:
                    return from_encodable(data=response.json(), load_with=cast_to)
                elif is_binary_content_type(content_type):
                    return cast(
                        T,
                        BinaryResponse(
                            content=response.content, headers=response.headers
                        ),
                    )
                else:
                    return from_encodable(data=response.content, load_with=cast_to)
        else:
            try:
                response_json = response.json()
            except JSONDecodeError:
                raise ApiError(status_code=response.status_code, body=response.text)
            raise ApiError(status_code=response.status_code, body=response_json)


class SyncBaseClient(BaseClient):
    def __init__(
        self,
        *,
        base_url: str,
        httpx_client: httpx.Client,
    ):
        super().__init__(base_url=base_url)
        self.httpx_client = httpx_client

    def request(
        self,
        *,
        method: str,
        path: str,
        cast_to: Type[T],
        auth_names: Optional[List[str]] = None,
        query_params: Optional[QueryParams] = None,
        headers: Optional[Dict[str, str]] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        content_type: Optional[str] = None,
        content: Optional[httpx._types.RequestContent] = None,
        request_options: Optional[RequestOptions] = None,
    ) -> T:
        req_cfg = self.build_request(
            method=method,
            path=path,
            auth_names=auth_names,
            query_params=query_params,
            headers=headers,
            data=data,
            files=files,
            json=json,
            content_type=content_type,
            content=content,
            request_options=request_options,
        )

        response = self.httpx_client.request(**req_cfg)

        return self.process_response(response=response, cast_to=cast_to)


class AsyncBaseClient(BaseClient):
    def __init__(
        self,
        *,
        base_url: str,
        httpx_client: httpx.AsyncClient,
    ):
        super().__init__(base_url=base_url)
        self.httpx_client = httpx_client

    async def request(
        self,
        method: str,
        path: str,
        cast_to: Type[T],
        auth_names: Optional[List[str]] = None,
        query_params: Optional[QueryParams] = None,
        headers: Optional[Dict[str, str]] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        content_type: Optional[str] = None,
        content: Optional[httpx._types.RequestContent] = None,
        request_options: Optional[RequestOptions] = None,
    ) -> T:
        req_cfg = self.build_request(
            method=method,
            path=path,
            auth_names=auth_names,
            query_params=query_params,
            headers=headers,
            data=data,
            files=files,
            json=json,
            content_type=content_type,
            content=content,
            request_options=request_options,
        )

        response = await self.httpx_client.request(**req_cfg)

        return self.process_response(response=response, cast_to=cast_to)



"""
Generated by Sideko (sideko.dev)
"""

import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
)
from magic_hour.types import models


class VideoProjectsClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client
        # register sync resources

    # register sync api methods
    def get(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> models.GetV1VideoProjectsIdResponse:
        """
        Get the details of a video project. The `download` field will be `null` unless the video was successfully rendered.

        The video can be one of the following status
        - `draft` - not currently used
        - `queued` - the job is queued and waiting for a GPU
        - `rendering` - the generation is in progress
        - `complete` - the video is successful created
        - `error` - an error occurred during rendering
        - `canceled` - video render is canceled by the user


        GET /v1/video-projects/{id}
        """

        # start -- build request data

        # end -- build request data

        # start -- send sync request
        return self._base_client.request(
            method="GET",
            path=f"/v1/video-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=models.GetV1VideoProjectsIdResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send sync request

    def delete(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Permanently delete the rendered video. This action is not reversible, please be sure before deleting.

        DELETE /v1/video-projects/{id}
        """

        # start -- build request data

        # end -- build request data

        # start -- send sync request
        return self._base_client.request(
            method="DELETE",
            path=f"/v1/video-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=type(None),
            request_options=request_options or default_request_options(),
        )
        # end -- send sync request


class AsyncVideoProjectsClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client
        # register async resources

    # register async api methods
    async def get(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> models.GetV1VideoProjectsIdResponse:
        """
        Get the details of a video project. The `download` field will be `null` unless the video was successfully rendered.

        The video can be one of the following status
        - `draft` - not currently used
        - `queued` - the job is queued and waiting for a GPU
        - `rendering` - the generation is in progress
        - `complete` - the video is successful created
        - `error` - an error occurred during rendering
        - `canceled` - video render is canceled by the user


        GET /v1/video-projects/{id}
        """

        # start -- build request data

        # end -- build request data

        # start -- send async request
        return await self._base_client.request(
            method="GET",
            path=f"/v1/video-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=models.GetV1VideoProjectsIdResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send async request

    async def delete(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Permanently delete the rendered video. This action is not reversible, please be sure before deleting.

        DELETE /v1/video-projects/{id}
        """

        # start -- build request data

        # end -- build request data

        # start -- send async request
        return await self._base_client.request(
            method="DELETE",
            path=f"/v1/video-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=type(None),
            request_options=request_options or default_request_options(),
        )
        # end -- send async request



"""
Generated by Sideko (sideko.dev)
"""

"""File Generated by Sideko (sideko.dev)"""

from httpx._models import Headers


class BinaryResponse:
    content: bytes
    headers: Headers

    def __init__(self, content: bytes, headers: Headers) -> None:
        self.content = content
        self.headers = headers



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic


class PostV1ImageToVideoBodyStyle(typing_extensions.TypedDict):
    """
    PostV1ImageToVideoBodyStyle
    """

    prompt: typing.Optional[str]
    """
    The prompt used for the video.
    """


class _SerializerPostV1ImageToVideoBodyStyle(pydantic.BaseModel):
    """
    Serializer for PostV1ImageToVideoBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    prompt: typing.Optional[str] = pydantic.Field(alias="prompt")



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic

from .post_v1_ai_image_generator_body_style import (
    PostV1AiImageGeneratorBodyStyle,
    _SerializerPostV1AiImageGeneratorBodyStyle,
)


class PostV1AiImageGeneratorBody(typing_extensions.TypedDict):
    """
    PostV1AiImageGeneratorBody
    """

    image_count: typing_extensions.Required[float]
    """
    number to images to generate
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    orientation: typing_extensions.Required[
        typing_extensions.Literal["landscape", "portrait", "square"]
    ]

    style: typing_extensions.Required[PostV1AiImageGeneratorBodyStyle]


class _SerializerPostV1AiImageGeneratorBody(pydantic.BaseModel):
    """
    Serializer for PostV1AiImageGeneratorBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    image_count: float = pydantic.Field(alias="image_count")
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    orientation: typing_extensions.Literal["landscape", "portrait", "square"] = (
        pydantic.Field(alias="orientation")
    )
    style: _SerializerPostV1AiImageGeneratorBodyStyle = pydantic.Field(alias="style")



"""
Generated by Sideko (sideko.dev)
"""

import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
)
from magic_hour.types import models, params


class AiPhotoEditorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client
        # register sync resources

    # register sync api methods
    def create(
        self,
        *,
        data: typing.Optional[params.PostV1AiPhotoEditorBody] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.PostV1AiPhotoEditorResponse:
        """
        > **NOTE**: this API is still in early development stages, and should be avoided. Please reach out to us if you're interested in this API.

        Edit photo using AI. Each photo costs 10 frames.

        POST /v1/ai-photo-editor
        """

        # start -- build request data
        _json = to_encodable(
            item=data, dump_with=params._SerializerPostV1AiPhotoEditorBody
        )
        # end -- build request data

        # start -- send sync request
        return self._base_client.request(
            method="POST",
            path="/v1/ai-photo-editor",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.PostV1AiPhotoEditorResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send sync request


class AsyncAiPhotoEditorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client
        # register async resources

    # register async api methods
    async def create(
        self,
        *,
        data: typing.Optional[params.PostV1AiPhotoEditorBody] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.PostV1AiPhotoEditorResponse:
        """
        > **NOTE**: this API is still in early development stages, and should be avoided. Please reach out to us if you're interested in this API.

        Edit photo using AI. Each photo costs 10 frames.

        POST /v1/ai-photo-editor
        """

        # start -- build request data
        _json = to_encodable(
            item=data, dump_with=params._SerializerPostV1AiPhotoEditorBody
        )
        # end -- build request data

        # start -- send async request
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-photo-editor",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.PostV1AiPhotoEditorResponse,
            request_options=request_options or default_request_options(),
        )
        # end -- send async request



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['magic_hour',
 'magic_hour.core',
 'magic_hour.resources.v1',
 'magic_hour.resources.v1.ai_headshot_generator',
 'magic_hour.resources.v1.ai_image_generator',
 'magic_hour.resources.v1.ai_image_upscaler',
 'magic_hour.resources.v1.ai_photo_editor',
 'magic_hour.resources.v1.ai_qr_code_generator',
 'magic_hour.resources.v1.animation',
 'magic_hour.resources.v1.face_swap',
 'magic_hour.resources.v1.face_swap_photo',
 'magic_hour.resources.v1.files',
 'magic_hour.resources.v1.files.upload_urls',
 'magic_hour.resources.v1.image_projects',
 'magic_hour.resources.v1.image_to_video',
 'magic_hour.resources.v1.lip_sync',
 'magic_hour.resources.v1.text_to_video',
 'magic_hour.resources.v1.video_projects',
 'magic_hour.resources.v1.video_to_video',
 'magic_hour.types.models',
 'magic_hour.types.params']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.26.0,<0.27.0', 'pydantic>=2.5.0,<3.0.0', 'typing_extensions>=4.0.0']

setup_kwargs = {
    'name': 'magic-hour',
    'version': '0.5.0',
    'description': '',
    'long_description': '\n# Magic Hour API Python SDK\n\n## Overview\n\n# Introduction \n\nMagic Hour provides an API (beta) that can be integrated into your own application to generate videos using AI. \n\nWebhook documentation can be found [here](https://magichour.ai/docs/webhook).\n\nIf you have any questions, please reach out to us via [discord](https://discord.gg/JX5rgsZaJp).\n\n# Authentication\n\nEvery request requires an API key.\n\nTo get started, first generate your API key [here](https://magichour.ai/settings/developer).\n\nThen, add the `Authorization` header to the request.\n\n| Key | Value |\n|-|-|\n| Authorization | Bearer mhk_live_apikey |\n\n> **Warning**: any API call that renders a video will utilize frames in your account.\n\n\n### Synchronous Client\n\n```python\nfrom magic_hour import Client\nfrom os import getenv\n\nclient = Client(token=getenv("API_TOKEN"))\n```\n\n### Asynchronous Client\n\n```python\nfrom magic_hour import AsyncClient\nfrom os import getenv\n\nclient = AsyncClient(token=getenv("API_TOKEN"))\n```\n\n## Module Documentation and Snippets\n\n### [v1.ai_headshot_generator](magic_hour/resources/v1/ai_headshot_generator/README.md)\n\n* [create](magic_hour/resources/v1/ai_headshot_generator/README.md#create) - Create AI Headshots\n\n### [v1.ai_image_generator](magic_hour/resources/v1/ai_image_generator/README.md)\n\n* [create](magic_hour/resources/v1/ai_image_generator/README.md#create) - Create AI Images\n\n### [v1.ai_image_upscaler](magic_hour/resources/v1/ai_image_upscaler/README.md)\n\n* [create](magic_hour/resources/v1/ai_image_upscaler/README.md#create) - Create Upscaled Image\n\n### [v1.ai_photo_editor](magic_hour/resources/v1/ai_photo_editor/README.md)\n\n* [create](magic_hour/resources/v1/ai_photo_editor/README.md#create) - AI Photo Editor\n\n### [v1.ai_qr_code_generator](magic_hour/resources/v1/ai_qr_code_generator/README.md)\n\n* [create](magic_hour/resources/v1/ai_qr_code_generator/README.md#create) - Create AI QR Code\n\n### [v1.animation](magic_hour/resources/v1/animation/README.md)\n\n* [create](magic_hour/resources/v1/animation/README.md#create) - Create Animation\n\n### [v1.face_swap](magic_hour/resources/v1/face_swap/README.md)\n\n* [create](magic_hour/resources/v1/face_swap/README.md#create) - Create Face Swap video\n\n### [v1.face_swap_photo](magic_hour/resources/v1/face_swap_photo/README.md)\n\n* [create](magic_hour/resources/v1/face_swap_photo/README.md#create) - Create Face Swap Photo\n\n### [v1.files.upload_urls](magic_hour/resources/v1/files/upload_urls/README.md)\n\n* [create](magic_hour/resources/v1/files/upload_urls/README.md#create) - Generate asset upload urls\n\n### [v1.image_projects](magic_hour/resources/v1/image_projects/README.md)\n\n* [delete](magic_hour/resources/v1/image_projects/README.md#delete) - Delete image\n* [get](magic_hour/resources/v1/image_projects/README.md#get) - Get image project details\n\n### [v1.image_to_video](magic_hour/resources/v1/image_to_video/README.md)\n\n* [create](magic_hour/resources/v1/image_to_video/README.md#create) - Create Image-to-Video\n\n### [v1.lip_sync](magic_hour/resources/v1/lip_sync/README.md)\n\n* [create](magic_hour/resources/v1/lip_sync/README.md#create) - Create Lip Sync video\n\n### [v1.text_to_video](magic_hour/resources/v1/text_to_video/README.md)\n\n* [create](magic_hour/resources/v1/text_to_video/README.md#create) - Create Text-to-Video\n\n### [v1.video_projects](magic_hour/resources/v1/video_projects/README.md)\n\n* [delete](magic_hour/resources/v1/video_projects/README.md#delete) - Delete video\n* [get](magic_hour/resources/v1/video_projects/README.md#get) - Get video details\n\n### [v1.video_to_video](magic_hour/resources/v1/video_to_video/README.md)\n\n* [create](magic_hour/resources/v1/video_to_video/README.md#create) - Create Video-to-Video\n\n<!-- MODULE DOCS END -->\n',
    'author': 'None',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



"""
Generated by Sideko (sideko.dev)
"""

import typing
import typing_extensions
import pydantic

from .get_v1_image_projects_id_response_downloads_item import (
    GetV1ImageProjectsIdResponseDownloadsItem,
)
from .get_v1_image_projects_id_response_error import GetV1ImageProjectsIdResponseError


class GetV1ImageProjectsIdResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    created_at: str = pydantic.Field(alias="created_at")

    downloads: typing.List[GetV1ImageProjectsIdResponseDownloadsItem] = pydantic.Field(
        alias="downloads"
    )

    enabled: bool = pydantic.Field(alias="enabled")
    """
    Indicates whether the resource is deleted
    """

    error: typing.Optional[GetV1ImageProjectsIdResponseError] = pydantic.Field(
        alias="error", default=None
    )
    """
    In the case of an error, this object will contain the error encountered during video render
    """

    id: str = pydantic.Field(alias="id")
    """
    Unique ID of the image. This value can be used in the [get image project API](/api/tag/image-projects/get/v1/image-projects/{id}) to fetch additional details such as status
    """

    image_count: float = pydantic.Field(alias="image_count")
    """
    Number of images generated
    """

    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    """
    The name of the image.
    """

    status: typing_extensions.Literal[
        "canceled", "complete", "draft", "error", "queued", "rendering"
    ] = pydantic.Field(alias="status")
    """
    The status of the image.
    """

    total_frame_cost: float = pydantic.Field(alias="total_frame_cost")
    """
    The amount of frames used to generate the image.
    """

    type_field: typing_extensions.Literal[
        "AI_HEADSHOT",
        "AI_IMAGE",
        "FACE_SWAP",
        "IMAGE_UPSCALER",
        "PHOTO_EDITOR",
        "QR_CODE",
    ] = pydantic.Field(alias="type")



"""
Generated by Sideko (sideko.dev)
"""

from typing import Any, Union, Dict, Type, TypeVar, List
from pydantic import BaseModel

EncodableT = TypeVar(
    "EncodableT",
    bound=Union[
        object,
        str,
        int,
        float,
        None,
        BaseModel,
        List[Any],
        Dict[str, Any],
    ],
)


def from_encodable(*, data: Any, load_with: Type[EncodableT]) -> Any:
    class Caster(BaseModel):
        data: load_with  # type: ignore

    return Caster(data=data).data



"""
Generated by Sideko (sideko.dev)
"""

import typing_extensions
import pydantic


class PostV1TextToVideoBodyStyle(typing_extensions.TypedDict):
    """
    PostV1TextToVideoBodyStyle
    """

    prompt: typing_extensions.Required[str]
    """
    The prompt used for the video.
    """


class _SerializerPostV1TextToVideoBodyStyle(pydantic.BaseModel):
    """
    Serializer for PostV1TextToVideoBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    prompt: str = pydantic.Field(alias="prompt")
